@@ -5,12 +5,12 @@ package Swagger2::Markdown;
 Swagger2::Markdown - convert a Swagger2 spec to various markdown formats
 
 =for html
-<a href='https://travis-ci.org/G3S/swagger2-markdown?branch=master'><img src='https://travis-ci.org/G3S/swagger2-markdown.svg?branch=master' alt='Build Status' /></a>
-<a href='https://coveralls.io/r/G3S/swagger2-markdown?branch=master'><img src='https://coveralls.io/repos/G3S/swagger2-markdown/badge.png?branch=master' alt='Coverage Status' /></a>
+<a href='https://travis-ci.org/Humanstate/swagger2-markdown?branch=master'><img src='https://travis-ci.org/Humanstate/swagger2-markdown.svg?branch=master' alt='Build Status' /></a>
+<a href='https://coveralls.io/r/Humanstate/swagger2-markdown?branch=master'><img src='https://coveralls.io/repos/Humanstate/swagger2-markdown/badge.png?branch=master' alt='Coverage Status' /></a>
 
 =head1 VERSION
 
-0.06
+0.07
 
 =head1 SYNOPSIS
 
@@ -45,7 +45,7 @@ use Template;
 use Swagger2::Markdown::API::Blueprint;
 use Pod::Markdown;
 
-our $VERSION = '0.06';
+our $VERSION = '0.07';
 
 =head1 ATTRIBUTES
 
@@ -235,7 +235,7 @@ This library is free software; you can redistribute it and/or modify it under
 the same terms as Perl itself. If you would like to contribute documentation
 please raise an issue / pull request:
 
-    https://github.com/G3S/swagger2-markdown
+    https://github.com/Humanstate/swagger2-markdown
 
 =cut
 
